# coding=utf-8
# *** WARNING: this file was generated by Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from ._inputs import *
import pulumi_aws

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 cluster_subnet_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 system_node_subnet_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 admin_access_principal: Optional[pulumi.Input[str]] = None,
                 cert_manager_version: Optional[pulumi.Input[str]] = None,
                 certificate_arn: Optional[pulumi.Input[str]] = None,
                 cluster_endpoint_private_access: Optional[pulumi.Input[bool]] = None,
                 cluster_endpoint_public_access: Optional[pulumi.Input[bool]] = None,
                 cluster_version: Optional[pulumi.Input[str]] = None,
                 eks_iam_auth_controller_version: Optional[pulumi.Input[str]] = None,
                 enable_cert_manager: Optional[bool] = None,
                 enable_cloud_watch_agent: Optional[bool] = None,
                 enable_external_dns: Optional[bool] = None,
                 enable_external_ingress: Optional[bool] = None,
                 enable_internal_ingress: Optional[bool] = None,
                 enable_karpenter: Optional[bool] = None,
                 enable_otel: Optional[bool] = None,
                 enabled_cluster_log_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 external_dns_version: Optional[pulumi.Input[str]] = None,
                 ingress_config: Optional[pulumi.Input['IngressConfigArgs']] = None,
                 karpenter_version: Optional[pulumi.Input[str]] = None,
                 lb_type: Optional[pulumi.Input[str]] = None,
                 lets_encrypt_email: Optional[str] = None,
                 nginx_ingress_registry: Optional[pulumi.Input[str]] = None,
                 nginx_ingress_version: Optional[pulumi.Input[str]] = None,
                 system_node_desired_count: Optional[pulumi.Input[float]] = None,
                 system_node_instance_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 system_node_max_count: Optional[pulumi.Input[float]] = None,
                 system_node_min_count: Optional[pulumi.Input[float]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input[str] admin_access_principal: The ARN of the AWS principal that should get admin access.
        :param pulumi.Input[str] cert_manager_version: The version of the cert-manager helm chart to deploy.
        :param pulumi.Input[str] certificate_arn: The ARN of the certificate to use for the ingress controller.
        :param pulumi.Input[bool] cluster_endpoint_private_access: Indicates whether or not the Amazon EKS private API server endpoint is enabled.
        :param pulumi.Input[bool] cluster_endpoint_public_access: Indicates whether or not the Amazon EKS public API server endpoint is enabled.
        :param pulumi.Input[str] cluster_version: The version of the EKS cluster to create.
        :param pulumi.Input[str] eks_iam_auth_controller_version: The version of the eks-iam-auth-controller helm chart to deploy.
        :param bool enable_cert_manager: Whether to enable cert-manager with route 53 integration.
        :param bool enable_cloud_watch_agent: Whether to enable cloudwatch container insights for EKS.
        :param bool enable_external_dns: Whether to enable external dns with route 53 integration.
        :param bool enable_external_ingress: Whether to create an ingress controller for external traffic.
        :param bool enable_internal_ingress: Whether to create an ingress controller for internal traffic.
        :param bool enable_karpenter: Whether to enable karpenter.
        :param bool enable_otel: Whether to enable the OTEL Distro for EKS.
        :param pulumi.Input[str] external_dns_version: The version of the external-dns helm chart to deploy.
        :param pulumi.Input['IngressConfigArgs'] ingress_config: Configuration for the ingress controller.
        :param pulumi.Input[str] karpenter_version: The version of karpenter to deploy.
        :param pulumi.Input[str] lb_type: The type of loadbalancer to provision.
        :param str lets_encrypt_email: The email address to use to issue certificates from Lets Encrypt.
        :param pulumi.Input[str] nginx_ingress_registry: The container registry to pull images from.
        :param pulumi.Input[str] nginx_ingress_version: The version of the nginx ingress controller helm chart to deploy.
        :param pulumi.Input[float] system_node_desired_count: The initial number of nodes in the system autoscaling group.
        :param pulumi.Input[float] system_node_max_count: The maximum number of nodes in the system autoscaling group.
        :param pulumi.Input[float] system_node_min_count: The minimum number of nodes in the system autoscaling group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map of tags to apply to the cluster.
        """
        pulumi.set(__self__, "cluster_subnet_ids", cluster_subnet_ids)
        pulumi.set(__self__, "system_node_subnet_ids", system_node_subnet_ids)
        if admin_access_principal is not None:
            pulumi.set(__self__, "admin_access_principal", admin_access_principal)
        if cert_manager_version is not None:
            pulumi.set(__self__, "cert_manager_version", cert_manager_version)
        if certificate_arn is not None:
            pulumi.set(__self__, "certificate_arn", certificate_arn)
        if cluster_endpoint_private_access is None:
            cluster_endpoint_private_access = False
        if cluster_endpoint_private_access is not None:
            pulumi.set(__self__, "cluster_endpoint_private_access", cluster_endpoint_private_access)
        if cluster_endpoint_public_access is None:
            cluster_endpoint_public_access = True
        if cluster_endpoint_public_access is not None:
            pulumi.set(__self__, "cluster_endpoint_public_access", cluster_endpoint_public_access)
        if cluster_version is not None:
            pulumi.set(__self__, "cluster_version", cluster_version)
        if eks_iam_auth_controller_version is not None:
            pulumi.set(__self__, "eks_iam_auth_controller_version", eks_iam_auth_controller_version)
        if enable_cert_manager is None:
            enable_cert_manager = True
        if enable_cert_manager is not None:
            pulumi.set(__self__, "enable_cert_manager", enable_cert_manager)
        if enable_cloud_watch_agent is None:
            enable_cloud_watch_agent = False
        if enable_cloud_watch_agent is not None:
            pulumi.set(__self__, "enable_cloud_watch_agent", enable_cloud_watch_agent)
        if enable_external_dns is None:
            enable_external_dns = True
        if enable_external_dns is not None:
            pulumi.set(__self__, "enable_external_dns", enable_external_dns)
        if enable_external_ingress is None:
            enable_external_ingress = True
        if enable_external_ingress is not None:
            pulumi.set(__self__, "enable_external_ingress", enable_external_ingress)
        if enable_internal_ingress is None:
            enable_internal_ingress = True
        if enable_internal_ingress is not None:
            pulumi.set(__self__, "enable_internal_ingress", enable_internal_ingress)
        if enable_karpenter is None:
            enable_karpenter = True
        if enable_karpenter is not None:
            pulumi.set(__self__, "enable_karpenter", enable_karpenter)
        if enable_otel is None:
            enable_otel = False
        if enable_otel is not None:
            pulumi.set(__self__, "enable_otel", enable_otel)
        if enabled_cluster_log_types is not None:
            pulumi.set(__self__, "enabled_cluster_log_types", enabled_cluster_log_types)
        if external_dns_version is not None:
            pulumi.set(__self__, "external_dns_version", external_dns_version)
        if ingress_config is not None:
            pulumi.set(__self__, "ingress_config", ingress_config)
        if karpenter_version is None:
            karpenter_version = '0.36.2'
        if karpenter_version is not None:
            pulumi.set(__self__, "karpenter_version", karpenter_version)
        if lb_type is None:
            lb_type = 'nlb'
        if lb_type is not None:
            pulumi.set(__self__, "lb_type", lb_type)
        if lets_encrypt_email is not None:
            pulumi.set(__self__, "lets_encrypt_email", lets_encrypt_email)
        if nginx_ingress_registry is None:
            nginx_ingress_registry = 'registry.k8s.io'
        if nginx_ingress_registry is not None:
            pulumi.set(__self__, "nginx_ingress_registry", nginx_ingress_registry)
        if nginx_ingress_version is not None:
            pulumi.set(__self__, "nginx_ingress_version", nginx_ingress_version)
        if system_node_desired_count is not None:
            pulumi.set(__self__, "system_node_desired_count", system_node_desired_count)
        if system_node_instance_types is not None:
            pulumi.set(__self__, "system_node_instance_types", system_node_instance_types)
        if system_node_max_count is not None:
            pulumi.set(__self__, "system_node_max_count", system_node_max_count)
        if system_node_min_count is not None:
            pulumi.set(__self__, "system_node_min_count", system_node_min_count)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="clusterSubnetIds")
    def cluster_subnet_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        return pulumi.get(self, "cluster_subnet_ids")

    @cluster_subnet_ids.setter
    def cluster_subnet_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "cluster_subnet_ids", value)

    @property
    @pulumi.getter(name="systemNodeSubnetIds")
    def system_node_subnet_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        return pulumi.get(self, "system_node_subnet_ids")

    @system_node_subnet_ids.setter
    def system_node_subnet_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "system_node_subnet_ids", value)

    @property
    @pulumi.getter(name="adminAccessPrincipal")
    def admin_access_principal(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the AWS principal that should get admin access.
        """
        return pulumi.get(self, "admin_access_principal")

    @admin_access_principal.setter
    def admin_access_principal(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "admin_access_principal", value)

    @property
    @pulumi.getter(name="certManagerVersion")
    def cert_manager_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the cert-manager helm chart to deploy.
        """
        return pulumi.get(self, "cert_manager_version")

    @cert_manager_version.setter
    def cert_manager_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cert_manager_version", value)

    @property
    @pulumi.getter(name="certificateArn")
    def certificate_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the certificate to use for the ingress controller.
        """
        return pulumi.get(self, "certificate_arn")

    @certificate_arn.setter
    def certificate_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "certificate_arn", value)

    @property
    @pulumi.getter(name="clusterEndpointPrivateAccess")
    def cluster_endpoint_private_access(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not the Amazon EKS private API server endpoint is enabled.
        """
        return pulumi.get(self, "cluster_endpoint_private_access")

    @cluster_endpoint_private_access.setter
    def cluster_endpoint_private_access(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "cluster_endpoint_private_access", value)

    @property
    @pulumi.getter(name="clusterEndpointPublicAccess")
    def cluster_endpoint_public_access(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not the Amazon EKS public API server endpoint is enabled.
        """
        return pulumi.get(self, "cluster_endpoint_public_access")

    @cluster_endpoint_public_access.setter
    def cluster_endpoint_public_access(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "cluster_endpoint_public_access", value)

    @property
    @pulumi.getter(name="clusterVersion")
    def cluster_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the EKS cluster to create.
        """
        return pulumi.get(self, "cluster_version")

    @cluster_version.setter
    def cluster_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_version", value)

    @property
    @pulumi.getter(name="eksIamAuthControllerVersion")
    def eks_iam_auth_controller_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the eks-iam-auth-controller helm chart to deploy.
        """
        return pulumi.get(self, "eks_iam_auth_controller_version")

    @eks_iam_auth_controller_version.setter
    def eks_iam_auth_controller_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eks_iam_auth_controller_version", value)

    @property
    @pulumi.getter(name="enableCertManager")
    def enable_cert_manager(self) -> Optional[bool]:
        """
        Whether to enable cert-manager with route 53 integration.
        """
        return pulumi.get(self, "enable_cert_manager")

    @enable_cert_manager.setter
    def enable_cert_manager(self, value: Optional[bool]):
        pulumi.set(self, "enable_cert_manager", value)

    @property
    @pulumi.getter(name="enableCloudWatchAgent")
    def enable_cloud_watch_agent(self) -> Optional[bool]:
        """
        Whether to enable cloudwatch container insights for EKS.
        """
        return pulumi.get(self, "enable_cloud_watch_agent")

    @enable_cloud_watch_agent.setter
    def enable_cloud_watch_agent(self, value: Optional[bool]):
        pulumi.set(self, "enable_cloud_watch_agent", value)

    @property
    @pulumi.getter(name="enableExternalDns")
    def enable_external_dns(self) -> Optional[bool]:
        """
        Whether to enable external dns with route 53 integration.
        """
        return pulumi.get(self, "enable_external_dns")

    @enable_external_dns.setter
    def enable_external_dns(self, value: Optional[bool]):
        pulumi.set(self, "enable_external_dns", value)

    @property
    @pulumi.getter(name="enableExternalIngress")
    def enable_external_ingress(self) -> Optional[bool]:
        """
        Whether to create an ingress controller for external traffic.
        """
        return pulumi.get(self, "enable_external_ingress")

    @enable_external_ingress.setter
    def enable_external_ingress(self, value: Optional[bool]):
        pulumi.set(self, "enable_external_ingress", value)

    @property
    @pulumi.getter(name="enableInternalIngress")
    def enable_internal_ingress(self) -> Optional[bool]:
        """
        Whether to create an ingress controller for internal traffic.
        """
        return pulumi.get(self, "enable_internal_ingress")

    @enable_internal_ingress.setter
    def enable_internal_ingress(self, value: Optional[bool]):
        pulumi.set(self, "enable_internal_ingress", value)

    @property
    @pulumi.getter(name="enableKarpenter")
    def enable_karpenter(self) -> Optional[bool]:
        """
        Whether to enable karpenter.
        """
        return pulumi.get(self, "enable_karpenter")

    @enable_karpenter.setter
    def enable_karpenter(self, value: Optional[bool]):
        pulumi.set(self, "enable_karpenter", value)

    @property
    @pulumi.getter(name="enableOtel")
    def enable_otel(self) -> Optional[bool]:
        """
        Whether to enable the OTEL Distro for EKS.
        """
        return pulumi.get(self, "enable_otel")

    @enable_otel.setter
    def enable_otel(self, value: Optional[bool]):
        pulumi.set(self, "enable_otel", value)

    @property
    @pulumi.getter(name="enabledClusterLogTypes")
    def enabled_cluster_log_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "enabled_cluster_log_types")

    @enabled_cluster_log_types.setter
    def enabled_cluster_log_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "enabled_cluster_log_types", value)

    @property
    @pulumi.getter(name="externalDNSVersion")
    def external_dns_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the external-dns helm chart to deploy.
        """
        return pulumi.get(self, "external_dns_version")

    @external_dns_version.setter
    def external_dns_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_dns_version", value)

    @property
    @pulumi.getter(name="ingressConfig")
    def ingress_config(self) -> Optional[pulumi.Input['IngressConfigArgs']]:
        """
        Configuration for the ingress controller.
        """
        return pulumi.get(self, "ingress_config")

    @ingress_config.setter
    def ingress_config(self, value: Optional[pulumi.Input['IngressConfigArgs']]):
        pulumi.set(self, "ingress_config", value)

    @property
    @pulumi.getter(name="karpenterVersion")
    def karpenter_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of karpenter to deploy.
        """
        return pulumi.get(self, "karpenter_version")

    @karpenter_version.setter
    def karpenter_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "karpenter_version", value)

    @property
    @pulumi.getter(name="lbType")
    def lb_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of loadbalancer to provision.
        """
        return pulumi.get(self, "lb_type")

    @lb_type.setter
    def lb_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lb_type", value)

    @property
    @pulumi.getter(name="letsEncryptEmail")
    def lets_encrypt_email(self) -> Optional[str]:
        """
        The email address to use to issue certificates from Lets Encrypt.
        """
        return pulumi.get(self, "lets_encrypt_email")

    @lets_encrypt_email.setter
    def lets_encrypt_email(self, value: Optional[str]):
        pulumi.set(self, "lets_encrypt_email", value)

    @property
    @pulumi.getter(name="nginxIngressRegistry")
    def nginx_ingress_registry(self) -> Optional[pulumi.Input[str]]:
        """
        The container registry to pull images from.
        """
        return pulumi.get(self, "nginx_ingress_registry")

    @nginx_ingress_registry.setter
    def nginx_ingress_registry(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nginx_ingress_registry", value)

    @property
    @pulumi.getter(name="nginxIngressVersion")
    def nginx_ingress_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the nginx ingress controller helm chart to deploy.
        """
        return pulumi.get(self, "nginx_ingress_version")

    @nginx_ingress_version.setter
    def nginx_ingress_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nginx_ingress_version", value)

    @property
    @pulumi.getter(name="systemNodeDesiredCount")
    def system_node_desired_count(self) -> Optional[pulumi.Input[float]]:
        """
        The initial number of nodes in the system autoscaling group.
        """
        return pulumi.get(self, "system_node_desired_count")

    @system_node_desired_count.setter
    def system_node_desired_count(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "system_node_desired_count", value)

    @property
    @pulumi.getter(name="systemNodeInstanceTypes")
    def system_node_instance_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "system_node_instance_types")

    @system_node_instance_types.setter
    def system_node_instance_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "system_node_instance_types", value)

    @property
    @pulumi.getter(name="systemNodeMaxCount")
    def system_node_max_count(self) -> Optional[pulumi.Input[float]]:
        """
        The maximum number of nodes in the system autoscaling group.
        """
        return pulumi.get(self, "system_node_max_count")

    @system_node_max_count.setter
    def system_node_max_count(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "system_node_max_count", value)

    @property
    @pulumi.getter(name="systemNodeMinCount")
    def system_node_min_count(self) -> Optional[pulumi.Input[float]]:
        """
        The minimum number of nodes in the system autoscaling group.
        """
        return pulumi.get(self, "system_node_min_count")

    @system_node_min_count.setter
    def system_node_min_count(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "system_node_min_count", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Key-value map of tags to apply to the cluster.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


class Cluster(pulumi.ComponentResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_access_principal: Optional[pulumi.Input[str]] = None,
                 cert_manager_version: Optional[pulumi.Input[str]] = None,
                 certificate_arn: Optional[pulumi.Input[str]] = None,
                 cluster_endpoint_private_access: Optional[pulumi.Input[bool]] = None,
                 cluster_endpoint_public_access: Optional[pulumi.Input[bool]] = None,
                 cluster_subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cluster_version: Optional[pulumi.Input[str]] = None,
                 eks_iam_auth_controller_version: Optional[pulumi.Input[str]] = None,
                 enable_cert_manager: Optional[bool] = None,
                 enable_cloud_watch_agent: Optional[bool] = None,
                 enable_external_dns: Optional[bool] = None,
                 enable_external_ingress: Optional[bool] = None,
                 enable_internal_ingress: Optional[bool] = None,
                 enable_karpenter: Optional[bool] = None,
                 enable_otel: Optional[bool] = None,
                 enabled_cluster_log_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 external_dns_version: Optional[pulumi.Input[str]] = None,
                 ingress_config: Optional[pulumi.Input[pulumi.InputType['IngressConfigArgs']]] = None,
                 karpenter_version: Optional[pulumi.Input[str]] = None,
                 lb_type: Optional[pulumi.Input[str]] = None,
                 lets_encrypt_email: Optional[str] = None,
                 nginx_ingress_registry: Optional[pulumi.Input[str]] = None,
                 nginx_ingress_version: Optional[pulumi.Input[str]] = None,
                 system_node_desired_count: Optional[pulumi.Input[float]] = None,
                 system_node_instance_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 system_node_max_count: Optional[pulumi.Input[float]] = None,
                 system_node_min_count: Optional[pulumi.Input[float]] = None,
                 system_node_subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Create a Cluster resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] admin_access_principal: The ARN of the AWS principal that should get admin access.
        :param pulumi.Input[str] cert_manager_version: The version of the cert-manager helm chart to deploy.
        :param pulumi.Input[str] certificate_arn: The ARN of the certificate to use for the ingress controller.
        :param pulumi.Input[bool] cluster_endpoint_private_access: Indicates whether or not the Amazon EKS private API server endpoint is enabled.
        :param pulumi.Input[bool] cluster_endpoint_public_access: Indicates whether or not the Amazon EKS public API server endpoint is enabled.
        :param pulumi.Input[str] cluster_version: The version of the EKS cluster to create.
        :param pulumi.Input[str] eks_iam_auth_controller_version: The version of the eks-iam-auth-controller helm chart to deploy.
        :param bool enable_cert_manager: Whether to enable cert-manager with route 53 integration.
        :param bool enable_cloud_watch_agent: Whether to enable cloudwatch container insights for EKS.
        :param bool enable_external_dns: Whether to enable external dns with route 53 integration.
        :param bool enable_external_ingress: Whether to create an ingress controller for external traffic.
        :param bool enable_internal_ingress: Whether to create an ingress controller for internal traffic.
        :param bool enable_karpenter: Whether to enable karpenter.
        :param bool enable_otel: Whether to enable the OTEL Distro for EKS.
        :param pulumi.Input[str] external_dns_version: The version of the external-dns helm chart to deploy.
        :param pulumi.Input[pulumi.InputType['IngressConfigArgs']] ingress_config: Configuration for the ingress controller.
        :param pulumi.Input[str] karpenter_version: The version of karpenter to deploy.
        :param pulumi.Input[str] lb_type: The type of loadbalancer to provision.
        :param str lets_encrypt_email: The email address to use to issue certificates from Lets Encrypt.
        :param pulumi.Input[str] nginx_ingress_registry: The container registry to pull images from.
        :param pulumi.Input[str] nginx_ingress_version: The version of the nginx ingress controller helm chart to deploy.
        :param pulumi.Input[float] system_node_desired_count: The initial number of nodes in the system autoscaling group.
        :param pulumi.Input[float] system_node_max_count: The maximum number of nodes in the system autoscaling group.
        :param pulumi.Input[float] system_node_min_count: The minimum number of nodes in the system autoscaling group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map of tags to apply to the cluster.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Cluster resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_access_principal: Optional[pulumi.Input[str]] = None,
                 cert_manager_version: Optional[pulumi.Input[str]] = None,
                 certificate_arn: Optional[pulumi.Input[str]] = None,
                 cluster_endpoint_private_access: Optional[pulumi.Input[bool]] = None,
                 cluster_endpoint_public_access: Optional[pulumi.Input[bool]] = None,
                 cluster_subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cluster_version: Optional[pulumi.Input[str]] = None,
                 eks_iam_auth_controller_version: Optional[pulumi.Input[str]] = None,
                 enable_cert_manager: Optional[bool] = None,
                 enable_cloud_watch_agent: Optional[bool] = None,
                 enable_external_dns: Optional[bool] = None,
                 enable_external_ingress: Optional[bool] = None,
                 enable_internal_ingress: Optional[bool] = None,
                 enable_karpenter: Optional[bool] = None,
                 enable_otel: Optional[bool] = None,
                 enabled_cluster_log_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 external_dns_version: Optional[pulumi.Input[str]] = None,
                 ingress_config: Optional[pulumi.Input[pulumi.InputType['IngressConfigArgs']]] = None,
                 karpenter_version: Optional[pulumi.Input[str]] = None,
                 lb_type: Optional[pulumi.Input[str]] = None,
                 lets_encrypt_email: Optional[str] = None,
                 nginx_ingress_registry: Optional[pulumi.Input[str]] = None,
                 nginx_ingress_version: Optional[pulumi.Input[str]] = None,
                 system_node_desired_count: Optional[pulumi.Input[float]] = None,
                 system_node_instance_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 system_node_max_count: Optional[pulumi.Input[float]] = None,
                 system_node_min_count: Optional[pulumi.Input[float]] = None,
                 system_node_subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is not None:
            raise ValueError('ComponentResource classes do not support opts.id')
        else:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["admin_access_principal"] = admin_access_principal
            __props__.__dict__["cert_manager_version"] = cert_manager_version
            __props__.__dict__["certificate_arn"] = certificate_arn
            if cluster_endpoint_private_access is None:
                cluster_endpoint_private_access = False
            __props__.__dict__["cluster_endpoint_private_access"] = cluster_endpoint_private_access
            if cluster_endpoint_public_access is None:
                cluster_endpoint_public_access = True
            __props__.__dict__["cluster_endpoint_public_access"] = cluster_endpoint_public_access
            if cluster_subnet_ids is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_subnet_ids'")
            __props__.__dict__["cluster_subnet_ids"] = cluster_subnet_ids
            __props__.__dict__["cluster_version"] = cluster_version
            __props__.__dict__["eks_iam_auth_controller_version"] = eks_iam_auth_controller_version
            if enable_cert_manager is None:
                enable_cert_manager = True
            __props__.__dict__["enable_cert_manager"] = enable_cert_manager
            if enable_cloud_watch_agent is None:
                enable_cloud_watch_agent = False
            __props__.__dict__["enable_cloud_watch_agent"] = enable_cloud_watch_agent
            if enable_external_dns is None:
                enable_external_dns = True
            __props__.__dict__["enable_external_dns"] = enable_external_dns
            if enable_external_ingress is None:
                enable_external_ingress = True
            __props__.__dict__["enable_external_ingress"] = enable_external_ingress
            if enable_internal_ingress is None:
                enable_internal_ingress = True
            __props__.__dict__["enable_internal_ingress"] = enable_internal_ingress
            if enable_karpenter is None:
                enable_karpenter = True
            __props__.__dict__["enable_karpenter"] = enable_karpenter
            if enable_otel is None:
                enable_otel = False
            __props__.__dict__["enable_otel"] = enable_otel
            __props__.__dict__["enabled_cluster_log_types"] = enabled_cluster_log_types
            __props__.__dict__["external_dns_version"] = external_dns_version
            __props__.__dict__["ingress_config"] = ingress_config
            if karpenter_version is None:
                karpenter_version = '0.36.2'
            __props__.__dict__["karpenter_version"] = karpenter_version
            if lb_type is None:
                lb_type = 'nlb'
            __props__.__dict__["lb_type"] = lb_type
            __props__.__dict__["lets_encrypt_email"] = lets_encrypt_email
            if nginx_ingress_registry is None:
                nginx_ingress_registry = 'registry.k8s.io'
            __props__.__dict__["nginx_ingress_registry"] = nginx_ingress_registry
            __props__.__dict__["nginx_ingress_version"] = nginx_ingress_version
            __props__.__dict__["system_node_desired_count"] = system_node_desired_count
            __props__.__dict__["system_node_instance_types"] = system_node_instance_types
            __props__.__dict__["system_node_max_count"] = system_node_max_count
            __props__.__dict__["system_node_min_count"] = system_node_min_count
            if system_node_subnet_ids is None and not opts.urn:
                raise TypeError("Missing required property 'system_node_subnet_ids'")
            __props__.__dict__["system_node_subnet_ids"] = system_node_subnet_ids
            __props__.__dict__["tags"] = tags
            __props__.__dict__["cluster_name"] = None
            __props__.__dict__["control_plane"] = None
            __props__.__dict__["karpenter_node_role"] = None
            __props__.__dict__["kubeconfig"] = None
            __props__.__dict__["oidc_provider"] = None
            __props__.__dict__["system_nodes"] = None
        super(Cluster, __self__).__init__(
            'lbrlabs-eks:index:Cluster',
            resource_name,
            __props__,
            opts,
            remote=True)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[str]:
        """
        The cluster name
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter(name="controlPlane")
    def control_plane(self) -> pulumi.Output['pulumi_aws.eks.Cluster']:
        """
        The Cluster control plane
        """
        return pulumi.get(self, "control_plane")

    @property
    @pulumi.getter(name="karpenterNodeRole")
    def karpenter_node_role(self) -> pulumi.Output[Optional['pulumi_aws.iam.Role']]:
        """
        The role created for karpenter nodes.
        """
        return pulumi.get(self, "karpenter_node_role")

    @property
    @pulumi.getter
    def kubeconfig(self) -> pulumi.Output[str]:
        """
        The kubeconfig for this cluster.
        """
        return pulumi.get(self, "kubeconfig")

    @property
    @pulumi.getter(name="oidcProvider")
    def oidc_provider(self) -> pulumi.Output['pulumi_aws.iam.OpenIdConnectProvider']:
        """
        The OIDC provider for this cluster.
        """
        return pulumi.get(self, "oidc_provider")

    @property
    @pulumi.getter(name="systemNodes")
    def system_nodes(self) -> pulumi.Output['pulumi_aws.eks.NodeGroup']:
        """
        The system node group.
        """
        return pulumi.get(self, "system_nodes")




# coding=utf-8
# *** WARNING: this file was generated by Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
import pulumi_aws

__all__ = ['IamServiceAccountRoleArgs', 'IamServiceAccountRole']

@pulumi.input_type
class IamServiceAccountRoleArgs:
    def __init__(__self__, *,
                 namespace_name: pulumi.Input[str],
                 oidc_provider_arn: pulumi.Input[str],
                 oidc_provider_url: pulumi.Input[str],
                 service_account_name: pulumi.Input[str],
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a IamServiceAccountRole resource.
        :param pulumi.Input[str] namespace_name: The namespace to create the service account in.
        :param pulumi.Input[str] oidc_provider_arn: The arn of the OIDC provider attached to your EKS cluster.
        :param pulumi.Input[str] oidc_provider_url: The URL of the OIDC provider attached to your EKS cluster.
        :param pulumi.Input[str] service_account_name: The name of the service account to bind to the role
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map of tags to apply to the service account.
        """
        pulumi.set(__self__, "namespace_name", namespace_name)
        pulumi.set(__self__, "oidc_provider_arn", oidc_provider_arn)
        pulumi.set(__self__, "oidc_provider_url", oidc_provider_url)
        pulumi.set(__self__, "service_account_name", service_account_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="namespaceName")
    def namespace_name(self) -> pulumi.Input[str]:
        """
        The namespace to create the service account in.
        """
        return pulumi.get(self, "namespace_name")

    @namespace_name.setter
    def namespace_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace_name", value)

    @property
    @pulumi.getter(name="oidcProviderArn")
    def oidc_provider_arn(self) -> pulumi.Input[str]:
        """
        The arn of the OIDC provider attached to your EKS cluster.
        """
        return pulumi.get(self, "oidc_provider_arn")

    @oidc_provider_arn.setter
    def oidc_provider_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "oidc_provider_arn", value)

    @property
    @pulumi.getter(name="oidcProviderUrl")
    def oidc_provider_url(self) -> pulumi.Input[str]:
        """
        The URL of the OIDC provider attached to your EKS cluster.
        """
        return pulumi.get(self, "oidc_provider_url")

    @oidc_provider_url.setter
    def oidc_provider_url(self, value: pulumi.Input[str]):
        pulumi.set(self, "oidc_provider_url", value)

    @property
    @pulumi.getter(name="serviceAccountName")
    def service_account_name(self) -> pulumi.Input[str]:
        """
        The name of the service account to bind to the role
        """
        return pulumi.get(self, "service_account_name")

    @service_account_name.setter
    def service_account_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_account_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Key-value map of tags to apply to the service account.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


class IamServiceAccountRole(pulumi.ComponentResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 namespace_name: Optional[pulumi.Input[str]] = None,
                 oidc_provider_arn: Optional[pulumi.Input[str]] = None,
                 oidc_provider_url: Optional[pulumi.Input[str]] = None,
                 service_account_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Create a IamServiceAccountRole resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] namespace_name: The namespace to create the service account in.
        :param pulumi.Input[str] oidc_provider_arn: The arn of the OIDC provider attached to your EKS cluster.
        :param pulumi.Input[str] oidc_provider_url: The URL of the OIDC provider attached to your EKS cluster.
        :param pulumi.Input[str] service_account_name: The name of the service account to bind to the role
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map of tags to apply to the service account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IamServiceAccountRoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a IamServiceAccountRole resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param IamServiceAccountRoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IamServiceAccountRoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 namespace_name: Optional[pulumi.Input[str]] = None,
                 oidc_provider_arn: Optional[pulumi.Input[str]] = None,
                 oidc_provider_url: Optional[pulumi.Input[str]] = None,
                 service_account_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is not None:
            raise ValueError('ComponentResource classes do not support opts.id')
        else:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IamServiceAccountRoleArgs.__new__(IamServiceAccountRoleArgs)

            if namespace_name is None and not opts.urn:
                raise TypeError("Missing required property 'namespace_name'")
            __props__.__dict__["namespace_name"] = namespace_name
            if oidc_provider_arn is None and not opts.urn:
                raise TypeError("Missing required property 'oidc_provider_arn'")
            __props__.__dict__["oidc_provider_arn"] = oidc_provider_arn
            if oidc_provider_url is None and not opts.urn:
                raise TypeError("Missing required property 'oidc_provider_url'")
            __props__.__dict__["oidc_provider_url"] = oidc_provider_url
            if service_account_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_account_name'")
            __props__.__dict__["service_account_name"] = service_account_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["role"] = None
        super(IamServiceAccountRole, __self__).__init__(
            'lbrlabs-eks:index:IamServiceAccountRole',
            resource_name,
            __props__,
            opts,
            remote=True)

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output['pulumi_aws.iam.Role']:
        return pulumi.get(self, "role")




# coding=utf-8
# *** WARNING: this file was generated by Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from ._inputs import *
import pulumi_kubernetes

__all__ = ['AutoscaledNodeGroupArgs', 'AutoscaledNodeGroup']

@pulumi.input_type
class AutoscaledNodeGroupArgs:
    def __init__(__self__, *,
                 disk_size: Optional[pulumi.Input[str]] = None,
                 node_role: pulumi.Input[str],
                 requirements: pulumi.Input[Sequence[pulumi.Input['RequirementArgs']]],
                 security_group_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 subnet_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 ami_family: Optional[pulumi.Input[str]] = None,
                 ami_id: Optional[pulumi.Input[str]] = None,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 disruption: Optional[pulumi.Input['DisruptionConfigArgs']] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 taints: Optional[pulumi.Input[Sequence[pulumi.Input['pulumi_kubernetes.core.v1.TaintArgs']]]] = None):
        """
        The set of arguments for constructing a AutoscaledNodeGroup resource.
        :param pulumi.Input[str] disk_size: Disk size for the node group.
        :param pulumi.Input[str] node_role: Node role for the node group.
        :param pulumi.Input[Sequence[pulumi.Input['RequirementArgs']]] requirements: List of requirements for the node group.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: List of security group selector terms for the node group.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subnet_ids: List of subnet selector terms for the node group.
        :param pulumi.Input[str] ami_family: AMI family for the node group.
        :param pulumi.Input[str] ami_id: AMI ID for the node group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations to apply to the node group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Key-value map of Kubernetes labels. Only labels that are applied with the EKS API are managed by this argument. Other Kubernetes labels applied to the EKS Node Group will not be managed.
        :param pulumi.Input[Sequence[pulumi.Input['pulumi_kubernetes.core.v1.TaintArgs']]] taints: Optional node taints.
        """
        if disk_size is None:
            disk_size = '20Gi'
        pulumi.set(__self__, "disk_size", disk_size)
        pulumi.set(__self__, "node_role", node_role)
        pulumi.set(__self__, "requirements", requirements)
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        pulumi.set(__self__, "subnet_ids", subnet_ids)
        if ami_family is not None:
            pulumi.set(__self__, "ami_family", ami_family)
        if ami_id is not None:
            pulumi.set(__self__, "ami_id", ami_id)
        if annotations is not None:
            pulumi.set(__self__, "annotations", annotations)
        if disruption is not None:
            pulumi.set(__self__, "disruption", disruption)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if taints is not None:
            pulumi.set(__self__, "taints", taints)

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> pulumi.Input[str]:
        """
        Disk size for the node group.
        """
        return pulumi.get(self, "disk_size")

    @disk_size.setter
    def disk_size(self, value: pulumi.Input[str]):
        pulumi.set(self, "disk_size", value)

    @property
    @pulumi.getter(name="nodeRole")
    def node_role(self) -> pulumi.Input[str]:
        """
        Node role for the node group.
        """
        return pulumi.get(self, "node_role")

    @node_role.setter
    def node_role(self, value: pulumi.Input[str]):
        pulumi.set(self, "node_role", value)

    @property
    @pulumi.getter
    def requirements(self) -> pulumi.Input[Sequence[pulumi.Input['RequirementArgs']]]:
        """
        List of requirements for the node group.
        """
        return pulumi.get(self, "requirements")

    @requirements.setter
    def requirements(self, value: pulumi.Input[Sequence[pulumi.Input['RequirementArgs']]]):
        pulumi.set(self, "requirements", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        List of security group selector terms for the node group.
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        List of subnet selector terms for the node group.
        """
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter(name="amiFamily")
    def ami_family(self) -> Optional[pulumi.Input[str]]:
        """
        AMI family for the node group.
        """
        return pulumi.get(self, "ami_family")

    @ami_family.setter
    def ami_family(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ami_family", value)

    @property
    @pulumi.getter(name="amiId")
    def ami_id(self) -> Optional[pulumi.Input[str]]:
        """
        AMI ID for the node group.
        """
        return pulumi.get(self, "ami_id")

    @ami_id.setter
    def ami_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ami_id", value)

    @property
    @pulumi.getter
    def annotations(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Annotations to apply to the node group.
        """
        return pulumi.get(self, "annotations")

    @annotations.setter
    def annotations(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "annotations", value)

    @property
    @pulumi.getter
    def disruption(self) -> Optional[pulumi.Input['DisruptionConfigArgs']]:
        return pulumi.get(self, "disruption")

    @disruption.setter
    def disruption(self, value: Optional[pulumi.Input['DisruptionConfigArgs']]):
        pulumi.set(self, "disruption", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Key-value map of Kubernetes labels. Only labels that are applied with the EKS API are managed by this argument. Other Kubernetes labels applied to the EKS Node Group will not be managed.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def taints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['pulumi_kubernetes.core.v1.TaintArgs']]]]:
        """
        Optional node taints.
        """
        return pulumi.get(self, "taints")

    @taints.setter
    def taints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['pulumi_kubernetes.core.v1.TaintArgs']]]]):
        pulumi.set(self, "taints", value)


class AutoscaledNodeGroup(pulumi.ComponentResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ami_family: Optional[pulumi.Input[str]] = None,
                 ami_id: Optional[pulumi.Input[str]] = None,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 disk_size: Optional[pulumi.Input[str]] = None,
                 disruption: Optional[pulumi.Input[pulumi.InputType['DisruptionConfigArgs']]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 node_role: Optional[pulumi.Input[str]] = None,
                 requirements: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RequirementArgs']]]]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 taints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['pulumi_kubernetes.core.v1.TaintArgs']]]]] = None,
                 __props__=None):
        """
        Create a AutoscaledNodeGroup resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ami_family: AMI family for the node group.
        :param pulumi.Input[str] ami_id: AMI ID for the node group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] annotations: Annotations to apply to the node group.
        :param pulumi.Input[str] disk_size: Disk size for the node group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Key-value map of Kubernetes labels. Only labels that are applied with the EKS API are managed by this argument. Other Kubernetes labels applied to the EKS Node Group will not be managed.
        :param pulumi.Input[str] node_role: Node role for the node group.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RequirementArgs']]]] requirements: List of requirements for the node group.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: List of security group selector terms for the node group.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subnet_ids: List of subnet selector terms for the node group.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['pulumi_kubernetes.core.v1.TaintArgs']]]] taints: Optional node taints.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AutoscaledNodeGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a AutoscaledNodeGroup resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param AutoscaledNodeGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AutoscaledNodeGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ami_family: Optional[pulumi.Input[str]] = None,
                 ami_id: Optional[pulumi.Input[str]] = None,
                 annotations: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 disk_size: Optional[pulumi.Input[str]] = None,
                 disruption: Optional[pulumi.Input[pulumi.InputType['DisruptionConfigArgs']]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 node_role: Optional[pulumi.Input[str]] = None,
                 requirements: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RequirementArgs']]]]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 taints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['pulumi_kubernetes.core.v1.TaintArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is not None:
            raise ValueError('ComponentResource classes do not support opts.id')
        else:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AutoscaledNodeGroupArgs.__new__(AutoscaledNodeGroupArgs)

            __props__.__dict__["ami_family"] = ami_family
            __props__.__dict__["ami_id"] = ami_id
            __props__.__dict__["annotations"] = annotations
            if disk_size is None:
                disk_size = '20Gi'
            if disk_size is None and not opts.urn:
                raise TypeError("Missing required property 'disk_size'")
            __props__.__dict__["disk_size"] = disk_size
            __props__.__dict__["disruption"] = disruption
            __props__.__dict__["labels"] = labels
            if node_role is None and not opts.urn:
                raise TypeError("Missing required property 'node_role'")
            __props__.__dict__["node_role"] = node_role
            if requirements is None and not opts.urn:
                raise TypeError("Missing required property 'requirements'")
            __props__.__dict__["requirements"] = requirements
            if security_group_ids is None and not opts.urn:
                raise TypeError("Missing required property 'security_group_ids'")
            __props__.__dict__["security_group_ids"] = security_group_ids
            if subnet_ids is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_ids'")
            __props__.__dict__["subnet_ids"] = subnet_ids
            __props__.__dict__["taints"] = taints
        super(AutoscaledNodeGroup, __self__).__init__(
            'lbrlabs-eks:index:AutoscaledNodeGroup',
            resource_name,
            __props__,
            opts,
            remote=True)




# coding=utf-8
# *** WARNING: this file was generated by Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['IamRoleMappingArgs', 'IamRoleMapping']

@pulumi.input_type
class IamRoleMappingArgs:
    def __init__(__self__, *,
                 groups: pulumi.Input[Sequence[pulumi.Input[str]]],
                 role_arn: pulumi.Input[str],
                 username: pulumi.Input[str]):
        """
        The set of arguments for constructing a IamRoleMapping resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] groups: An array of groups to map the IAM role to.
        :param pulumi.Input[str] role_arn: The arn of the role to map to a Kubernetes group.
        :param pulumi.Input[str] username: The username to assign to the rolemapping.
        """
        pulumi.set(__self__, "groups", groups)
        pulumi.set(__self__, "role_arn", role_arn)
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def groups(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        An array of groups to map the IAM role to.
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "groups", value)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Input[str]:
        """
        The arn of the role to map to a Kubernetes group.
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter
    def username(self) -> pulumi.Input[str]:
        """
        The username to assign to the rolemapping.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[str]):
        pulumi.set(self, "username", value)


class IamRoleMapping(pulumi.ComponentResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a IamRoleMapping resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] groups: An array of groups to map the IAM role to.
        :param pulumi.Input[str] role_arn: The arn of the role to map to a Kubernetes group.
        :param pulumi.Input[str] username: The username to assign to the rolemapping.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IamRoleMappingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a IamRoleMapping resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param IamRoleMappingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IamRoleMappingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is not None:
            raise ValueError('ComponentResource classes do not support opts.id')
        else:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IamRoleMappingArgs.__new__(IamRoleMappingArgs)

            if groups is None and not opts.urn:
                raise TypeError("Missing required property 'groups'")
            __props__.__dict__["groups"] = groups
            if role_arn is None and not opts.urn:
                raise TypeError("Missing required property 'role_arn'")
            __props__.__dict__["role_arn"] = role_arn
            if username is None and not opts.urn:
                raise TypeError("Missing required property 'username'")
            __props__.__dict__["username"] = username
        super(IamRoleMapping, __self__).__init__(
            'lbrlabs-eks:index:IamRoleMapping',
            resource_name,
            __props__,
            opts,
            remote=True)




# coding=utf-8
# *** WARNING: this file was generated by Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
import pulumi_aws

__all__ = ['AttachedNodeGroupArgs', 'AttachedNodeGroup']

@pulumi.input_type
class AttachedNodeGroupArgs:
    def __init__(__self__, *,
                 cluster_name: pulumi.Input[str],
                 subnet_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 ami_type: Optional[pulumi.Input[str]] = None,
                 capacity_type: Optional[pulumi.Input[str]] = None,
                 disk_size: Optional[pulumi.Input[int]] = None,
                 instance_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 release_version: Optional[pulumi.Input[str]] = None,
                 scaling_config: Optional[pulumi.Input['pulumi_aws.eks.NodeGroupScalingConfigArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 taints: Optional[pulumi.Input[Sequence[pulumi.Input['pulumi_aws.eks.NodeGroupTaintArgs']]]] = None):
        """
        The set of arguments for constructing a AttachedNodeGroup resource.
        :param pulumi.Input[str] cluster_name: The cluster name to attach the nodegroup tp.
        :param pulumi.Input[str] ami_type: The AMI Type for the nodegroup.
        :param pulumi.Input[str] capacity_type: The capacity type of the nodegroup.
        :param pulumi.Input[int] disk_size: The size of the disk to attach to the nodes.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Key-value map of Kubernetes labels. Only labels that are applied with the EKS API are managed by this argument. Other Kubernetes labels applied to the EKS Node Group will not be managed.
        :param pulumi.Input[str] release_version: The release version for the nodegroup.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map of tags to apply to the nodegroup.
        """
        pulumi.set(__self__, "cluster_name", cluster_name)
        pulumi.set(__self__, "subnet_ids", subnet_ids)
        if ami_type is not None:
            pulumi.set(__self__, "ami_type", ami_type)
        if capacity_type is None:
            capacity_type = 'ON_DEMAND'
        if capacity_type is not None:
            pulumi.set(__self__, "capacity_type", capacity_type)
        if disk_size is None:
            disk_size = 20
        if disk_size is not None:
            pulumi.set(__self__, "disk_size", disk_size)
        if instance_types is not None:
            pulumi.set(__self__, "instance_types", instance_types)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if release_version is not None:
            pulumi.set(__self__, "release_version", release_version)
        if scaling_config is not None:
            pulumi.set(__self__, "scaling_config", scaling_config)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if taints is not None:
            pulumi.set(__self__, "taints", taints)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Input[str]:
        """
        The cluster name to attach the nodegroup tp.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter(name="amiType")
    def ami_type(self) -> Optional[pulumi.Input[str]]:
        """
        The AMI Type for the nodegroup.
        """
        return pulumi.get(self, "ami_type")

    @ami_type.setter
    def ami_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ami_type", value)

    @property
    @pulumi.getter(name="capacityType")
    def capacity_type(self) -> Optional[pulumi.Input[str]]:
        """
        The capacity type of the nodegroup.
        """
        return pulumi.get(self, "capacity_type")

    @capacity_type.setter
    def capacity_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "capacity_type", value)

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> Optional[pulumi.Input[int]]:
        """
        The size of the disk to attach to the nodes.
        """
        return pulumi.get(self, "disk_size")

    @disk_size.setter
    def disk_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "disk_size", value)

    @property
    @pulumi.getter(name="instanceTypes")
    def instance_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "instance_types")

    @instance_types.setter
    def instance_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "instance_types", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Key-value map of Kubernetes labels. Only labels that are applied with the EKS API are managed by this argument. Other Kubernetes labels applied to the EKS Node Group will not be managed.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter(name="releaseVersion")
    def release_version(self) -> Optional[pulumi.Input[str]]:
        """
        The release version for the nodegroup.
        """
        return pulumi.get(self, "release_version")

    @release_version.setter
    def release_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "release_version", value)

    @property
    @pulumi.getter(name="scalingConfig")
    def scaling_config(self) -> Optional[pulumi.Input['pulumi_aws.eks.NodeGroupScalingConfigArgs']]:
        return pulumi.get(self, "scaling_config")

    @scaling_config.setter
    def scaling_config(self, value: Optional[pulumi.Input['pulumi_aws.eks.NodeGroupScalingConfigArgs']]):
        pulumi.set(self, "scaling_config", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Key-value map of tags to apply to the nodegroup.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def taints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['pulumi_aws.eks.NodeGroupTaintArgs']]]]:
        return pulumi.get(self, "taints")

    @taints.setter
    def taints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['pulumi_aws.eks.NodeGroupTaintArgs']]]]):
        pulumi.set(self, "taints", value)


class AttachedNodeGroup(pulumi.ComponentResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ami_type: Optional[pulumi.Input[str]] = None,
                 capacity_type: Optional[pulumi.Input[str]] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 disk_size: Optional[pulumi.Input[int]] = None,
                 instance_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 release_version: Optional[pulumi.Input[str]] = None,
                 scaling_config: Optional[pulumi.Input[pulumi.InputType['pulumi_aws.eks.NodeGroupScalingConfigArgs']]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 taints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['pulumi_aws.eks.NodeGroupTaintArgs']]]]] = None,
                 __props__=None):
        """
        Create a AttachedNodeGroup resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ami_type: The AMI Type for the nodegroup.
        :param pulumi.Input[str] capacity_type: The capacity type of the nodegroup.
        :param pulumi.Input[str] cluster_name: The cluster name to attach the nodegroup tp.
        :param pulumi.Input[int] disk_size: The size of the disk to attach to the nodes.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: Key-value map of Kubernetes labels. Only labels that are applied with the EKS API are managed by this argument. Other Kubernetes labels applied to the EKS Node Group will not be managed.
        :param pulumi.Input[str] release_version: The release version for the nodegroup.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map of tags to apply to the nodegroup.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AttachedNodeGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a AttachedNodeGroup resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param AttachedNodeGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AttachedNodeGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ami_type: Optional[pulumi.Input[str]] = None,
                 capacity_type: Optional[pulumi.Input[str]] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 disk_size: Optional[pulumi.Input[int]] = None,
                 instance_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 release_version: Optional[pulumi.Input[str]] = None,
                 scaling_config: Optional[pulumi.Input[pulumi.InputType['pulumi_aws.eks.NodeGroupScalingConfigArgs']]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 taints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['pulumi_aws.eks.NodeGroupTaintArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is not None:
            raise ValueError('ComponentResource classes do not support opts.id')
        else:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AttachedNodeGroupArgs.__new__(AttachedNodeGroupArgs)

            __props__.__dict__["ami_type"] = ami_type
            if capacity_type is None:
                capacity_type = 'ON_DEMAND'
            __props__.__dict__["capacity_type"] = capacity_type
            if cluster_name is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_name'")
            __props__.__dict__["cluster_name"] = cluster_name
            if disk_size is None:
                disk_size = 20
            __props__.__dict__["disk_size"] = disk_size
            __props__.__dict__["instance_types"] = instance_types
            __props__.__dict__["labels"] = labels
            __props__.__dict__["release_version"] = release_version
            __props__.__dict__["scaling_config"] = scaling_config
            if subnet_ids is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_ids'")
            __props__.__dict__["subnet_ids"] = subnet_ids
            __props__.__dict__["tags"] = tags
            __props__.__dict__["taints"] = taints
            __props__.__dict__["node_group"] = None
            __props__.__dict__["node_role"] = None
        super(AttachedNodeGroup, __self__).__init__(
            'lbrlabs-eks:index:AttachedNodeGroup',
            resource_name,
            __props__,
            opts,
            remote=True)

    @property
    @pulumi.getter(name="nodeGroup")
    def node_group(self) -> pulumi.Output['pulumi_aws.eks.NodeGroup']:
        return pulumi.get(self, "node_group")

    @property
    @pulumi.getter(name="nodeRole")
    def node_role(self) -> pulumi.Output['pulumi_aws.iam.Role']:
        return pulumi.get(self, "node_role")




# coding=utf-8
# *** WARNING: this file was generated by Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .attached_fargate_profile import *
from .attached_node_group import *
from .autoscaled_node_group import *
from .cluster import *
from .iam_role_mapping import *
from .iam_service_account_role import *
from .provider import *
from ._inputs import *
_utilities.register(
    resource_modules="""
[
 {
  "pkg": "lbrlabs-eks",
  "mod": "index",
  "fqn": "lbrlabs_pulumi_eks",
  "classes": {
   "lbrlabs-eks:index:AttachedFargateProfile": "AttachedFargateProfile",
   "lbrlabs-eks:index:AttachedNodeGroup": "AttachedNodeGroup",
   "lbrlabs-eks:index:AutoscaledNodeGroup": "AutoscaledNodeGroup",
   "lbrlabs-eks:index:Cluster": "Cluster",
   "lbrlabs-eks:index:IamRoleMapping": "IamRoleMapping",
   "lbrlabs-eks:index:IamServiceAccountRole": "IamServiceAccountRole"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "lbrlabs-eks",
  "token": "pulumi:providers:lbrlabs-eks",
  "fqn": "lbrlabs_pulumi_eks",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
import pulumi_aws

__all__ = ['AttachedFargateProfileArgs', 'AttachedFargateProfile']

@pulumi.input_type
class AttachedFargateProfileArgs:
    def __init__(__self__, *,
                 cluster_name: pulumi.Input[str],
                 selectors: pulumi.Input[Sequence[pulumi.Input['pulumi_aws.eks.FargateProfileSelectorArgs']]],
                 subnet_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a AttachedFargateProfile resource.
        :param pulumi.Input[str] cluster_name: The name of the cluster to assign the fargate profile to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subnet_ids: The subnet IDs to use for the fargate profile.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map for tags to apply to Fargate Profile.
        """
        pulumi.set(__self__, "cluster_name", cluster_name)
        pulumi.set(__self__, "selectors", selectors)
        pulumi.set(__self__, "subnet_ids", subnet_ids)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Input[str]:
        """
        The name of the cluster to assign the fargate profile to.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def selectors(self) -> pulumi.Input[Sequence[pulumi.Input['pulumi_aws.eks.FargateProfileSelectorArgs']]]:
        return pulumi.get(self, "selectors")

    @selectors.setter
    def selectors(self, value: pulumi.Input[Sequence[pulumi.Input['pulumi_aws.eks.FargateProfileSelectorArgs']]]):
        pulumi.set(self, "selectors", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The subnet IDs to use for the fargate profile.
        """
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Key-value map for tags to apply to Fargate Profile.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


class AttachedFargateProfile(pulumi.ComponentResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 selectors: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['pulumi_aws.eks.FargateProfileSelectorArgs']]]]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Create a AttachedFargateProfile resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_name: The name of the cluster to assign the fargate profile to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] subnet_ids: The subnet IDs to use for the fargate profile.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Key-value map for tags to apply to Fargate Profile.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AttachedFargateProfileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a AttachedFargateProfile resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param AttachedFargateProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AttachedFargateProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 selectors: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['pulumi_aws.eks.FargateProfileSelectorArgs']]]]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is not None:
            raise ValueError('ComponentResource classes do not support opts.id')
        else:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AttachedFargateProfileArgs.__new__(AttachedFargateProfileArgs)

            if cluster_name is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_name'")
            __props__.__dict__["cluster_name"] = cluster_name
            if selectors is None and not opts.urn:
                raise TypeError("Missing required property 'selectors'")
            __props__.__dict__["selectors"] = selectors
            if subnet_ids is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_ids'")
            __props__.__dict__["subnet_ids"] = subnet_ids
            __props__.__dict__["tags"] = tags
            __props__.__dict__["profile"] = None
            __props__.__dict__["role"] = None
        super(AttachedFargateProfile, __self__).__init__(
            'lbrlabs-eks:index:AttachedFargateProfile',
            resource_name,
            __props__,
            opts,
            remote=True)

    @property
    @pulumi.getter
    def profile(self) -> pulumi.Output['pulumi_aws.eks.FargateProfile']:
        return pulumi.get(self, "profile")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output['pulumi_aws.iam.Role']:
        return pulumi.get(self, "role")




# coding=utf-8
# *** WARNING: this file was generated by Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'BudgetConfigArgs',
    'DisruptionConfigArgs',
    'IngressConfigArgs',
    'RequirementArgs',
]

@pulumi.input_type
class BudgetConfigArgs:
    def __init__(__self__, *,
                 duration: Optional[pulumi.Input[str]] = None,
                 nodes: Optional[pulumi.Input[str]] = None,
                 schedule: Optional[pulumi.Input[str]] = None):
        """
        Configuration for Autoscaled Node budgets.
        :param pulumi.Input[str] duration: The duration during which disruptuon can happen.
        :param pulumi.Input[str] nodes: The maximum number of nodes that can be scaled down at any time.
        :param pulumi.Input[str] schedule: A cron schedule for when disruption can happen.
        """
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[str]]:
        """
        The duration during which disruptuon can happen.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[str]]:
        """
        The maximum number of nodes that can be scaled down at any time.
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input[str]]:
        """
        A cron schedule for when disruption can happen.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schedule", value)


@pulumi.input_type
class DisruptionConfigArgs:
    def __init__(__self__, *,
                 budgets: Optional[pulumi.Input[Sequence[pulumi.Input['BudgetConfigArgs']]]] = None,
                 consolidate_after: Optional[pulumi.Input[str]] = None,
                 consolidation_policy: Optional[pulumi.Input[str]] = None,
                 expire_after: Optional[pulumi.Input[str]] = None):
        """
        Configuration for Autoscaled nodes disruption.
        :param pulumi.Input[Sequence[pulumi.Input['BudgetConfigArgs']]] budgets: Budgets control the speed Karpenter can scale down nodes.
        :param pulumi.Input[str] consolidate_after: The amount of time Karpenter should wait after discovering a consolidation decision. This value can currently only be set when the consolidationPolicy is 'WhenEmpty'. You can choose to disable consolidation entirely by setting the string value 'Never' here.
        :param pulumi.Input[str] consolidation_policy: Describes which types of Nodes Karpenter should consider for consolidation.
        :param pulumi.Input[str] expire_after: The amount of time a Node can live on the cluster before being removed.
        """
        if budgets is not None:
            pulumi.set(__self__, "budgets", budgets)
        if consolidate_after is not None:
            pulumi.set(__self__, "consolidate_after", consolidate_after)
        if consolidation_policy is None:
            consolidation_policy = 'WhenEmpty'
        if consolidation_policy is not None:
            pulumi.set(__self__, "consolidation_policy", consolidation_policy)
        if expire_after is not None:
            pulumi.set(__self__, "expire_after", expire_after)

    @property
    @pulumi.getter
    def budgets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BudgetConfigArgs']]]]:
        """
        Budgets control the speed Karpenter can scale down nodes.
        """
        return pulumi.get(self, "budgets")

    @budgets.setter
    def budgets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BudgetConfigArgs']]]]):
        pulumi.set(self, "budgets", value)

    @property
    @pulumi.getter(name="consolidateAfter")
    def consolidate_after(self) -> Optional[pulumi.Input[str]]:
        """
        The amount of time Karpenter should wait after discovering a consolidation decision. This value can currently only be set when the consolidationPolicy is 'WhenEmpty'. You can choose to disable consolidation entirely by setting the string value 'Never' here.
        """
        return pulumi.get(self, "consolidate_after")

    @consolidate_after.setter
    def consolidate_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "consolidate_after", value)

    @property
    @pulumi.getter(name="consolidationPolicy")
    def consolidation_policy(self) -> Optional[pulumi.Input[str]]:
        """
        Describes which types of Nodes Karpenter should consider for consolidation.
        """
        return pulumi.get(self, "consolidation_policy")

    @consolidation_policy.setter
    def consolidation_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "consolidation_policy", value)

    @property
    @pulumi.getter(name="expireAfter")
    def expire_after(self) -> Optional[pulumi.Input[str]]:
        """
        The amount of time a Node can live on the cluster before being removed.
        """
        return pulumi.get(self, "expire_after")

    @expire_after.setter
    def expire_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expire_after", value)


@pulumi.input_type
class IngressConfigArgs:
    def __init__(__self__, *,
                 additional_config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 controller_replicas: Optional[pulumi.Input[int]] = None,
                 enable_metrics: Optional[pulumi.Input[bool]] = None,
                 enable_service_monitor: Optional[pulumi.Input[bool]] = None,
                 nlb_target_type: Optional[pulumi.Input[str]] = None,
                 service_monitor_namespace: Optional[pulumi.Input[str]] = None):
        """
        Configuration for the ingress controller.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_config: Additional configuration for the ingress controller.
        :param pulumi.Input[int] controller_replicas: The number of replicas of the ingress controller.
        :param pulumi.Input[bool] enable_metrics: Enable metrics for the ingress controller.
        :param pulumi.Input[bool] enable_service_monitor: Enable the service monitor for kube-prometheus-stackl.
        :param pulumi.Input[str] nlb_target_type: NLB target type for NLB loadbalancers.
        :param pulumi.Input[str] service_monitor_namespace: The namespace to deploy the service monitor to.
        """
        if additional_config is not None:
            pulumi.set(__self__, "additional_config", additional_config)
        if controller_replicas is None:
            controller_replicas = 1
        if controller_replicas is not None:
            pulumi.set(__self__, "controller_replicas", controller_replicas)
        if enable_metrics is None:
            enable_metrics = False
        if enable_metrics is not None:
            pulumi.set(__self__, "enable_metrics", enable_metrics)
        if enable_service_monitor is None:
            enable_service_monitor = False
        if enable_service_monitor is not None:
            pulumi.set(__self__, "enable_service_monitor", enable_service_monitor)
        if nlb_target_type is None:
            nlb_target_type = 'ip'
        if nlb_target_type is not None:
            pulumi.set(__self__, "nlb_target_type", nlb_target_type)
        if service_monitor_namespace is not None:
            pulumi.set(__self__, "service_monitor_namespace", service_monitor_namespace)

    @property
    @pulumi.getter(name="additionalConfig")
    def additional_config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Additional configuration for the ingress controller.
        """
        return pulumi.get(self, "additional_config")

    @additional_config.setter
    def additional_config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "additional_config", value)

    @property
    @pulumi.getter(name="controllerReplicas")
    def controller_replicas(self) -> Optional[pulumi.Input[int]]:
        """
        The number of replicas of the ingress controller.
        """
        return pulumi.get(self, "controller_replicas")

    @controller_replicas.setter
    def controller_replicas(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "controller_replicas", value)

    @property
    @pulumi.getter(name="enableMetrics")
    def enable_metrics(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable metrics for the ingress controller.
        """
        return pulumi.get(self, "enable_metrics")

    @enable_metrics.setter
    def enable_metrics(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_metrics", value)

    @property
    @pulumi.getter(name="enableServiceMonitor")
    def enable_service_monitor(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable the service monitor for kube-prometheus-stackl.
        """
        return pulumi.get(self, "enable_service_monitor")

    @enable_service_monitor.setter
    def enable_service_monitor(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_service_monitor", value)

    @property
    @pulumi.getter(name="nlbTargetType")
    def nlb_target_type(self) -> Optional[pulumi.Input[str]]:
        """
        NLB target type for NLB loadbalancers.
        """
        return pulumi.get(self, "nlb_target_type")

    @nlb_target_type.setter
    def nlb_target_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nlb_target_type", value)

    @property
    @pulumi.getter(name="serviceMonitorNamespace")
    def service_monitor_namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to deploy the service monitor to.
        """
        return pulumi.get(self, "service_monitor_namespace")

    @service_monitor_namespace.setter
    def service_monitor_namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_monitor_namespace", value)


@pulumi.input_type
class RequirementArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[str]] = None,
                 operator: Optional[pulumi.Input[str]] = None,
                 values: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Represents a single requirement with key, operator, and values.
        :param pulumi.Input[str] key: The key of the requirement.
        :param pulumi.Input[str] operator: The operator for the requirement (e.g., In, Gt).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] values: The list of values for the requirement.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        The key of the requirement.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def operator(self) -> Optional[pulumi.Input[str]]:
        """
        The operator for the requirement (e.g., In, Gt).
        """
        return pulumi.get(self, "operator")

    @operator.setter
    def operator(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "operator", value)

    @property
    @pulumi.getter
    def values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of values for the requirement.
        """
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "values", value)


